pub trait Kernel {
type Param;
// Required method
fn new(location: Self::Param, bandwidth: Self::Param) -> Self;
// Provided method
fn from_triple(triple: Triple<Self::Param>) -> Option<Self>
where Self: Sized,
Self::Param: Copy + Ord + Additive { ... }
}Expand description
A single kernel of a kernel density estimator.
Note that it does not directly correspond to the mathematical definition,
as for example, it is responsible for its own shift and scaling.
This is useful for discrete kernels which do not normally have a bandwidth parameter h.
Required Associated Types
Required Methods
Provided Methods
Object Safety
This trait is not object safe.